# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speaker_diarization/v1/speaker_diarization.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/speaker_diarization/v1/speaker_diarization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKphonexia/grpc/technologies/speaker_diarization/v1/speaker_diarization.proto\x12\x31phonexia.grpc.technologies.speaker_diarization.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x8e\x01\n\x0e\x44iarizeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12P\n\x06\x63onfig\x18\x02 \x01(\x0b\x32@.phonexia.grpc.technologies.speaker_diarization.v1.DiarizeConfig\"k\n\rDiarizeConfig\x12\x19\n\x0cmax_speakers\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1b\n\x0etotal_speakers\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0f\n\r_max_speakersB\x11\n\x0f_total_speakers\"\xe4\x01\n\x0f\x44iarizeResponse\x12\x16\n\x0espeakers_count\x18\x01 \x01(\x05\x12L\n\x08segments\x18\x02 \x03(\x0b\x32:.phonexia.grpc.technologies.speaker_diarization.v1.Segment\x12\x39\n\x16processed_audio_length\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x30\n\rspeech_length\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"y\n\x07Segment\x12\x12\n\nspeaker_id\x18\x01 \x01(\x05\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration2\xa9\x01\n\x12SpeakerDiarization\x12\x92\x01\n\x07\x44iarize\x12\x41.phonexia.grpc.technologies.speaker_diarization.v1.DiarizeRequest\x1a\x42.phonexia.grpc.technologies.speaker_diarization.v1.DiarizeResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speaker_diarization.v1.speaker_diarization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DIARIZEREQUEST']._serialized_start=196
  _globals['_DIARIZEREQUEST']._serialized_end=338
  _globals['_DIARIZECONFIG']._serialized_start=340
  _globals['_DIARIZECONFIG']._serialized_end=447
  _globals['_DIARIZERESPONSE']._serialized_start=450
  _globals['_DIARIZERESPONSE']._serialized_end=678
  _globals['_SEGMENT']._serialized_start=680
  _globals['_SEGMENT']._serialized_end=801
  _globals['_SPEAKERDIARIZATION']._serialized_start=804
  _globals['_SPEAKERDIARIZATION']._serialized_end=973
# @@protoc_insertion_point(module_scope)
