# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/time_analysis/v1/time_analysis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/time_analysis/v1/time_analysis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?phonexia/grpc/technologies/time_analysis/v1/time_analysis.proto\x12+phonexia.grpc.technologies.time_analysis.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"<\n\x0e\x41nalyzeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\xbc\x02\n\x10ReactionAnalysis\x12\x18\n\x10reacting_channel\x18\x01 \x01(\x05\x12\x17\n\x0freactions_count\x18\x02 \x01(\x04\x12\x38\n\x15\x61verage_reaction_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x42\n\x19\x66\x61stest_reaction_position\x18\x04 \x01(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\x12\x42\n\x19slowest_reaction_position\x18\x05 \x01(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\x12\x33\n\ncrosstalks\x18\x06 \x03(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\"\xb6\x01\n\x0f\x43hannelAnalysis\x12\x16\n\x0e\x63hannel_number\x18\x01 \x01(\x05\x12\x30\n\rspeech_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x18\n\x0bspeech_rate\x18\x03 \x01(\x02H\x00\x88\x01\x01\x12/\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\n\x0c_speech_rate\"\xc1\x01\n\rAnalyzeResult\x12V\n\x10\x63hannel_analyses\x18\x01 \x03(\x0b\x32<.phonexia.grpc.technologies.time_analysis.v1.ChannelAnalysis\x12X\n\x11reaction_analyses\x18\x02 \x03(\x0b\x32=.phonexia.grpc.technologies.time_analysis.v1.ReactionAnalysis\"\x98\x01\n\x0f\x41nalyzeResponse\x12J\n\x06result\x18\x01 \x01(\x0b\x32:.phonexia.grpc.technologies.time_analysis.v1.AnalyzeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\x99\x01\n\x0cTimeAnalysis\x12\x88\x01\n\x07\x41nalyze\x12;.phonexia.grpc.technologies.time_analysis.v1.AnalyzeRequest\x1a<.phonexia.grpc.technologies.time_analysis.v1.AnalyzeResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.time_analysis.v1.time_analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYZEREQUEST']._serialized_start=177
  _globals['_ANALYZEREQUEST']._serialized_end=237
  _globals['_REACTIONANALYSIS']._serialized_start=240
  _globals['_REACTIONANALYSIS']._serialized_end=556
  _globals['_CHANNELANALYSIS']._serialized_start=559
  _globals['_CHANNELANALYSIS']._serialized_end=741
  _globals['_ANALYZERESULT']._serialized_start=744
  _globals['_ANALYZERESULT']._serialized_end=937
  _globals['_ANALYZERESPONSE']._serialized_start=940
  _globals['_ANALYZERESPONSE']._serialized_end=1092
  _globals['_TIMEANALYSIS']._serialized_start=1095
  _globals['_TIMEANALYSIS']._serialized_end=1248
# @@protoc_insertion_point(module_scope)
