# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/licensing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/licensing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$phonexia/grpc/common/licensing.proto\x12\x14phonexia.grpc.common\"\x16\n\x14LicensingInfoRequest\"\x93\x02\n\x13LicensingInfoResult\x12\x13\n\x0bvalid_until\x18\x01 \x01(\t\x12\x10\n\x08is_valid\x18\x02 \x01(\x08\x12\x17\n\x0ftechnology_name\x18\x03 \x01(\t\x12\x33\n\nmodel_info\x18\x04 \x01(\x0b\x32\x1f.phonexia.grpc.common.ModelInfo\x12R\n\rlicense_flags\x18\x05 \x03(\x0b\x32;.phonexia.grpc.common.LicensingInfoResult.LicenseFlagsEntry\x1a\x33\n\x11LicenseFlagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\tModelInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t2j\n\tLicensing\x12]\n\x04Info\x12*.phonexia.grpc.common.LicensingInfoRequest\x1a).phonexia.grpc.common.LicensingInfoResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.licensing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._loaded_options = None
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._serialized_options = b'8\001'
  _globals['_LICENSINGINFOREQUEST']._serialized_start=62
  _globals['_LICENSINGINFOREQUEST']._serialized_end=84
  _globals['_LICENSINGINFORESULT']._serialized_start=87
  _globals['_LICENSINGINFORESULT']._serialized_end=362
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._serialized_start=311
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._serialized_end=362
  _globals['_MODELINFO']._serialized_start=364
  _globals['_MODELINFO']._serialized_end=406
  _globals['_LICENSING']._serialized_start=408
  _globals['_LICENSING']._serialized_end=514
# @@protoc_insertion_point(module_scope)
