# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/deepfake_detection/v1/deepfake_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/deepfake_detection/v1/deepfake_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIphonexia/grpc/technologies/deepfake_detection/v1/deepfake_detection.proto\x12\x30phonexia.grpc.technologies.deepfake_detection.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\x8b\x01\n\rDetectRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12N\n\x06\x63onfig\x18\x02 \x01(\x0b\x32>.phonexia.grpc.technologies.deepfake_detection.v1.DetectConfig\"@\n\x0c\x44\x65tectConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xab\x01\n\x0e\x44\x65tectResponse\x12S\n\x06result\x18\x01 \x01(\x0b\x32>.phonexia.grpc.technologies.deepfake_detection.v1.DetectResultH\x00\x88\x01\x01\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\n\x07_result\"O\n\x0c\x44\x65tectResult\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x30\n\rspeech_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xa3\x01\n\x11\x44\x65\x65pfakeDetection\x12\x8d\x01\n\x06\x44\x65tect\x12?.phonexia.grpc.technologies.deepfake_detection.v1.DetectRequest\x1a@.phonexia.grpc.technologies.deepfake_detection.v1.DetectResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.deepfake_detection.v1.deepfake_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST']._serialized_start=193
  _globals['_DETECTREQUEST']._serialized_end=332
  _globals['_DETECTCONFIG']._serialized_start=334
  _globals['_DETECTCONFIG']._serialized_end=398
  _globals['_DETECTRESPONSE']._serialized_start=401
  _globals['_DETECTRESPONSE']._serialized_end=572
  _globals['_DETECTRESULT']._serialized_start=574
  _globals['_DETECTRESULT']._serialized_end=653
  _globals['_DEEPFAKEDETECTION']._serialized_start=656
  _globals['_DEEPFAKEDETECTION']._serialized_end=819
# @@protoc_insertion_point(module_scope)
