# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/language_identification/v1/language_identification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/language_identification/v1/language_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSphonexia/grpc/technologies/language_identification/v1/language_identification.proto\x12\x35phonexia.grpc.technologies.language_identification.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xf1\x01\n\x0fIdentifyRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12U\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x45.phonexia.grpc.technologies.language_identification.v1.IdentifyConfig\x12[\n\rlanguageprint\x18\x03 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.Languageprint\"\xb2\x01\n\x10IdentifyResponse\x12\x63\n\x06result\x18\x01 \x01(\x0b\x32S.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x84\x01\n\x1dListSupportedLanguagesRequest\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32S.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesConfig\"r\n\x1eListSupportedLanguagesResponse\x12\x1b\n\x13supported_languages\x18\x01 \x03(\t\x12\x1a\n\x12modified_languages\x18\x02 \x03(\t\x12\x17\n\x0f\x61\x64\x64\x65\x64_languages\x18\x03 \x03(\t\"\x92\x01\n\x0e\x45xtractRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12T\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.ExtractConfig\"\xa2\x01\n\x0f\x45xtractResponse\x12T\n\x06result\x18\x01 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.ExtractResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"o\n\x0c\x41\x64\x61ptRequest\x12_\n\x10\x61\x64\x61ptation_units\x18\x01 \x03(\x0b\x32\x45.phonexia.grpc.technologies.language_identification.v1.AdaptationUnit\"h\n\rAdaptResponse\x12W\n\x06result\x18\x01 \x01(\x0b\x32G.phonexia.grpc.technologies.language_identification.v1.AdaptationResult\"\xd2\x02\n\x0eIdentifyConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12R\n\tlanguages\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.language_identification.v1.Language\x12T\n\x06groups\x18\x03 \x03(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.LanguageGroup\x12\x64\n\x12\x61\x64\x61ptation_profile\x18\x04 \x01(\x0b\x32H.phonexia.grpc.technologies.language_identification.v1.AdaptationProfile\"\x84\x01\n\x1cListSupportedLanguagesConfig\x12\x64\n\x12\x61\x64\x61ptation_profile\x18\x01 \x01(\x0b\x32H.phonexia.grpc.technologies.language_identification.v1.AdaptationProfile\"A\n\rExtractConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"!\n\x08Language\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\";\n\rLanguageGroup\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x16\n\x0elanguage_codes\x18\x02 \x03(\t\" \n\rLanguageprint\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\xb4\x01\n\x1cLanguageIdentificationResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x62\n\x06scores\x18\x02 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\"\xd4\x02\n\x1bLanguageIdentificationScore\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x12\x65\n\tlanguages\x18\x03 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\x12z\n\x0fidentifier_type\x18\x04 \x01(\x0e\x32\x61.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore.IdentifierType\")\n\x0eIdentifierType\x12\x0c\n\x08LANGUAGE\x10\x00\x12\t\n\x05GROUP\x10\x01\"\x9e\x01\n\rExtractResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12[\n\rlanguageprint\x18\x02 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.Languageprint\"\xc0\x01\n\x0e\x41\x64\x61ptationUnit\x12[\n\rlanguageprint\x18\x01 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.Languageprint\x12Q\n\x08language\x18\x02 \x01(\x0b\x32?.phonexia.grpc.technologies.language_identification.v1.Language\"$\n\x11\x41\x64\x61ptationProfile\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\xad\x01\n\x10\x41\x64\x61ptationResult\x12\x64\n\x12\x61\x64\x61ptation_profile\x18\x01 \x01(\x0b\x32H.phonexia.grpc.technologies.language_identification.v1.AdaptationProfile\x12\x1a\n\x12modified_languages\x18\x02 \x03(\t\x12\x17\n\x0f\x61\x64\x64\x65\x64_languages\x18\x03 \x03(\t2\xb4\x05\n\x16LanguageIdentification\x12\x9d\x01\n\x08Identify\x12\x46.phonexia.grpc.technologies.language_identification.v1.IdentifyRequest\x1aG.phonexia.grpc.technologies.language_identification.v1.IdentifyResponse(\x01\x12\xc5\x01\n\x16ListSupportedLanguages\x12T.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesRequest\x1aU.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesResponse\x12\x9a\x01\n\x07\x45xtract\x12\x45.phonexia.grpc.technologies.language_identification.v1.ExtractRequest\x1a\x46.phonexia.grpc.technologies.language_identification.v1.ExtractResponse(\x01\x12\x94\x01\n\x05\x41\x64\x61pt\x12\x43.phonexia.grpc.technologies.language_identification.v1.AdaptRequest\x1a\x44.phonexia.grpc.technologies.language_identification.v1.AdaptResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.language_identification.v1.language_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IDENTIFYREQUEST']._serialized_start=208
  _globals['_IDENTIFYREQUEST']._serialized_end=449
  _globals['_IDENTIFYRESPONSE']._serialized_start=452
  _globals['_IDENTIFYRESPONSE']._serialized_end=630
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_start=633
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_end=765
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_start=767
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_end=881
  _globals['_EXTRACTREQUEST']._serialized_start=884
  _globals['_EXTRACTREQUEST']._serialized_end=1030
  _globals['_EXTRACTRESPONSE']._serialized_start=1033
  _globals['_EXTRACTRESPONSE']._serialized_end=1195
  _globals['_ADAPTREQUEST']._serialized_start=1197
  _globals['_ADAPTREQUEST']._serialized_end=1308
  _globals['_ADAPTRESPONSE']._serialized_start=1310
  _globals['_ADAPTRESPONSE']._serialized_end=1414
  _globals['_IDENTIFYCONFIG']._serialized_start=1417
  _globals['_IDENTIFYCONFIG']._serialized_end=1755
  _globals['_LISTSUPPORTEDLANGUAGESCONFIG']._serialized_start=1758
  _globals['_LISTSUPPORTEDLANGUAGESCONFIG']._serialized_end=1890
  _globals['_EXTRACTCONFIG']._serialized_start=1892
  _globals['_EXTRACTCONFIG']._serialized_end=1957
  _globals['_LANGUAGE']._serialized_start=1959
  _globals['_LANGUAGE']._serialized_end=1992
  _globals['_LANGUAGEGROUP']._serialized_start=1994
  _globals['_LANGUAGEGROUP']._serialized_end=2053
  _globals['_LANGUAGEPRINT']._serialized_start=2055
  _globals['_LANGUAGEPRINT']._serialized_end=2087
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_start=2090
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_end=2270
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_start=2273
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_end=2613
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_start=2572
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_end=2613
  _globals['_EXTRACTRESULT']._serialized_start=2616
  _globals['_EXTRACTRESULT']._serialized_end=2774
  _globals['_ADAPTATIONUNIT']._serialized_start=2777
  _globals['_ADAPTATIONUNIT']._serialized_end=2969
  _globals['_ADAPTATIONPROFILE']._serialized_start=2971
  _globals['_ADAPTATIONPROFILE']._serialized_end=3007
  _globals['_ADAPTATIONRESULT']._serialized_start=3010
  _globals['_ADAPTATIONRESULT']._serialized_end=3183
  _globals['_LANGUAGEIDENTIFICATION']._serialized_start=3186
  _globals['_LANGUAGEIDENTIFICATION']._serialized_end=3878
# @@protoc_insertion_point(module_scope)
