"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia status definitions for gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.licensing_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___GetStatusRequest: typing_extensions.TypeAlias = GetStatusRequest

@typing.final
class GetStatusResponse(google.protobuf.message.Message):
    """Status response containing information about the micro-service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ConfigurationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.any_pb2.Any: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.any_pb2.Any | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    MODEL_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the service."""
    version: builtins.str
    """The version of the service."""
    @property
    def configuration(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.any_pb2.Any]:
        """The configuration of the service."""

    @property
    def model_info(self) -> phonexia.grpc.common.licensing_pb2.ModelInfo:
        """The model information."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
        configuration: collections.abc.Mapping[builtins.str, google.protobuf.any_pb2.Any] | None = ...,
        model_info: phonexia.grpc.common.licensing_pb2.ModelInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_model_info", b"_model_info", "model_info", b"model_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_model_info", b"_model_info", "configuration", b"configuration", "model_info", b"model_info", "name", b"name", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_model_info", b"_model_info"]) -> typing.Literal["model_info"] | None: ...

Global___GetStatusResponse: typing_extensions.TypeAlias = GetStatusResponse
