# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/gender_identification/v1/gender_identification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/gender_identification/v1/gender_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOphonexia/grpc/technologies/gender_identification/v1/gender_identification.proto\x12\x33phonexia.grpc.technologies.gender_identification.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xc9\x01\n\x0fIdentifyRequest\x12\x35\n\x0bvoiceprints\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12*\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x43.phonexia.grpc.technologies.gender_identification.v1.IdentifyConfig\"B\n\x0eIdentifyConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"/\n\x05Score\x12\x11\n\tscore_llr\x18\x01 \x01(\x02\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\"\x8e\x02\n\x0eIdentifyResult\x12S\n\nscore_male\x18\x01 \x01(\x0b\x32:.phonexia.grpc.technologies.gender_identification.v1.ScoreH\x00\x88\x01\x01\x12U\n\x0cscore_female\x18\x02 \x01(\x0b\x32:.phonexia.grpc.technologies.gender_identification.v1.ScoreH\x01\x88\x01\x01\x12\x30\n\rspeech_length\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\n\x0b_score_maleB\x0f\n\r_score_female\"\xa3\x01\n\x10IdentifyResponse\x12T\n\x07results\x18\x01 \x03(\x0b\x32\x43.phonexia.grpc.technologies.gender_identification.v1.IdentifyResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb4\x01\n\x14GenderIdentification\x12\x9b\x01\n\x08Identify\x12\x44.phonexia.grpc.technologies.gender_identification.v1.IdentifyRequest\x1a\x45.phonexia.grpc.technologies.gender_identification.v1.IdentifyResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.gender_identification.v1.gender_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IDENTIFYREQUEST']._serialized_start=202
  _globals['_IDENTIFYREQUEST']._serialized_end=403
  _globals['_IDENTIFYCONFIG']._serialized_start=405
  _globals['_IDENTIFYCONFIG']._serialized_end=471
  _globals['_SCORE']._serialized_start=473
  _globals['_SCORE']._serialized_end=520
  _globals['_IDENTIFYRESULT']._serialized_start=523
  _globals['_IDENTIFYRESULT']._serialized_end=793
  _globals['_IDENTIFYRESPONSE']._serialized_start=796
  _globals['_IDENTIFYRESPONSE']._serialized_end=959
  _globals['_GENDERIDENTIFICATION']._serialized_start=962
  _globals['_GENDERIDENTIFICATION']._serialized_end=1142
# @@protoc_insertion_point(module_scope)
