# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from phonexia.grpc.common import licensing_pb2 as phonexia_dot_grpc_dot_common_dot_licensing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!phonexia/grpc/common/status.proto\x12\x14phonexia.grpc.common\x1a\x19google/protobuf/any.proto\x1a$phonexia/grpc/common/licensing.proto\"\x12\n\x10GetStatusRequest\"\x9a\x02\n\x11GetStatusResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12Q\n\rconfiguration\x18\x03 \x03(\x0b\x32:.phonexia.grpc.common.GetStatusResponse.ConfigurationEntry\x12\x38\n\nmodel_info\x18\x04 \x01(\x0b\x32\x1f.phonexia.grpc.common.ModelInfoH\x00\x88\x01\x01\x1aJ\n\x12\x43onfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x42\r\n\x0b_model_info2f\n\x06Status\x12\\\n\tGetStatus\x12&.phonexia.grpc.common.GetStatusRequest\x1a\'.phonexia.grpc.common.GetStatusResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._loaded_options = None
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATUSREQUEST']._serialized_start=124
  _globals['_GETSTATUSREQUEST']._serialized_end=142
  _globals['_GETSTATUSRESPONSE']._serialized_start=145
  _globals['_GETSTATUSRESPONSE']._serialized_end=427
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._serialized_start=338
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._serialized_end=412
  _globals['_STATUS']._serialized_start=429
  _globals['_STATUS']._serialized_end=531
# @@protoc_insertion_point(module_scope)
