# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nuphonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper.proto\x12\x46phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\xa9\x01\n\x11TranscribeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12h\n\x06\x63onfig\x18\x02 \x01(\x0b\x32X.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeConfig\"i\n\x10TranscribeConfig\x12\x10\n\x08language\x18\x01 \x01(\t\x12!\n\x19\x65nable_language_switching\x18\x02 \x01(\x08\x12 \n\x18\x65nable_word_segmentation\x18\x03 \x01(\x08\"\xa7\x01\n\x10TranslateRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12g\n\x06\x63onfig\x18\x02 \x01(\x0b\x32W.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateConfig\"o\n\x0fTranslateConfig\x12\x17\n\x0fsource_language\x18\x01 \x01(\t\x12!\n\x19\x65nable_language_switching\x18\x02 \x01(\x08\x12 \n\x18\x65nable_word_segmentation\x18\x03 \x01(\x08\"\xb9\x01\n\x12TranscribeResponse\x12h\n\x06result\x18\x01 \x01(\x0b\x32X.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xb7\x01\n\x11TranslateResponse\x12g\n\x06result\x18\x01 \x01(\x0b\x32W.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1f\n\x1dListSupportedLanguagesRequest\"R\n\x1eListSupportedLanguagesResponse\x12\x11\n\tlanguages\x18\x01 \x03(\t\x12\x1d\n\x15translation_languages\x18\x02 \x03(\t\"u\n\x10TranscribeResult\x12\x61\n\x08one_best\x18\x01 \x01(\x0b\x32O.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.OneBest\"t\n\x0fTranslateResult\x12\x61\n\x08one_best\x18\x01 \x01(\x0b\x32O.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.OneBest\"s\n\x07OneBest\x12h\n\x08segments\x18\x01 \x03(\x0b\x32V.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.OneBestSegment\"\x89\x01\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x17\n\x0fpunctuated_text\x18\x04 \x01(\t\"\xa4\x02\n\x0eOneBestSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x17\n\x0fsource_language\x18\x05 \x01(\t\x12 \n\x18\x64\x65tected_source_language\x18\x06 \x01(\t\x12[\n\x05words\x18\x07 \x03(\x0b\x32L.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.Word2\x89\x05\n\x0cSpeechToText\x12\xc7\x01\n\nTranscribe\x12Y.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeRequest\x1aZ.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeResponse(\x01\x30\x01\x12\xc4\x01\n\tTranslate\x12X.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateRequest\x1aY.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateResponse(\x01\x30\x01\x12\xe7\x01\n\x16ListSupportedLanguages\x12\x65.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.ListSupportedLanguagesRequest\x1a\x66.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.ListSupportedLanguagesResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.enhanced_speech_to_text_built_on_whisper_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRANSCRIBEREQUEST']._serialized_start=259
  _globals['_TRANSCRIBEREQUEST']._serialized_end=428
  _globals['_TRANSCRIBECONFIG']._serialized_start=430
  _globals['_TRANSCRIBECONFIG']._serialized_end=535
  _globals['_TRANSLATEREQUEST']._serialized_start=538
  _globals['_TRANSLATEREQUEST']._serialized_end=705
  _globals['_TRANSLATECONFIG']._serialized_start=707
  _globals['_TRANSLATECONFIG']._serialized_end=818
  _globals['_TRANSCRIBERESPONSE']._serialized_start=821
  _globals['_TRANSCRIBERESPONSE']._serialized_end=1006
  _globals['_TRANSLATERESPONSE']._serialized_start=1009
  _globals['_TRANSLATERESPONSE']._serialized_end=1192
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_start=1194
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_end=1225
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_start=1227
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_end=1309
  _globals['_TRANSCRIBERESULT']._serialized_start=1311
  _globals['_TRANSCRIBERESULT']._serialized_end=1428
  _globals['_TRANSLATERESULT']._serialized_start=1430
  _globals['_TRANSLATERESULT']._serialized_end=1546
  _globals['_ONEBEST']._serialized_start=1548
  _globals['_ONEBEST']._serialized_end=1663
  _globals['_WORD']._serialized_start=1666
  _globals['_WORD']._serialized_end=1803
  _globals['_ONEBESTSEGMENT']._serialized_start=1806
  _globals['_ONEBESTSEGMENT']._serialized_end=2098
  _globals['_SPEECHTOTEXT']._serialized_start=2101
  _globals['_SPEECHTOTEXT']._serialized_end=2750
# @@protoc_insertion_point(module_scope)
