# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/age_estimation/v1/age_estimation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/age_estimation/v1/age_estimation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAphonexia/grpc/technologies/age_estimation/v1/age_estimation.proto\x12,phonexia.grpc.technologies.age_estimation.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xc2\x01\n\x0f\x45stimateRequest\x12\x35\n\x0bvoiceprints\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12*\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12L\n\x06\x63onfig\x18\x03 \x01(\x0b\x32<.phonexia.grpc.technologies.age_estimation.v1.EstimateConfig\"B\n\x0e\x45stimateConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\\\n\x0e\x45stimateResult\x12\x10\n\x03\x61ge\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x30\n\rspeech_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x06\n\x04_age\"\x9c\x01\n\x10\x45stimateResponse\x12M\n\x07results\x18\x01 \x03(\x0b\x32<.phonexia.grpc.technologies.age_estimation.v1.EstimateResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\x9f\x01\n\rAgeEstimation\x12\x8d\x01\n\x08\x45stimate\x12=.phonexia.grpc.technologies.age_estimation.v1.EstimateRequest\x1a>.phonexia.grpc.technologies.age_estimation.v1.EstimateResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.age_estimation.v1.age_estimation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ESTIMATEREQUEST']._serialized_start=181
  _globals['_ESTIMATEREQUEST']._serialized_end=375
  _globals['_ESTIMATECONFIG']._serialized_start=377
  _globals['_ESTIMATECONFIG']._serialized_end=443
  _globals['_ESTIMATERESULT']._serialized_start=445
  _globals['_ESTIMATERESULT']._serialized_end=537
  _globals['_ESTIMATERESPONSE']._serialized_start=540
  _globals['_ESTIMATERESPONSE']._serialized_end=696
  _globals['_AGEESTIMATION']._serialized_start=699
  _globals['_AGEESTIMATION']._serialized_end=858
# @@protoc_insertion_point(module_scope)
