# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/voice_activity_detection/v1/voice_activity_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/voice_activity_detection/v1/voice_activity_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUphonexia/grpc/technologies/voice_activity_detection/v1/voice_activity_detection.proto\x12\x36phonexia.grpc.technologies.voice_activity_detection.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\";\n\rDetectRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\xd0\x01\n\x0e\x44\x65tectResponse\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12Q\n\x08segments\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.voice_activity_detection.v1.Segment\x12\x39\n\x16processed_audio_length\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xda\x01\n\x07Segment\x12Y\n\x04type\x18\x01 \x01(\x0e\x32K.phonexia.grpc.technologies.voice_activity_detection.v1.Segment.SegmentType\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x18\n\x0bSegmentType\x12\t\n\x05VOICE\x10\x00\x32\xb4\x01\n\x16VoiceActivityDetection\x12\x99\x01\n\x06\x44\x65tect\x12\x45.phonexia.grpc.technologies.voice_activity_detection.v1.DetectRequest\x1a\x46.phonexia.grpc.technologies.voice_activity_detection.v1.DetectResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.voice_activity_detection.v1.voice_activity_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST']._serialized_start=210
  _globals['_DETECTREQUEST']._serialized_end=269
  _globals['_DETECTRESPONSE']._serialized_start=272
  _globals['_DETECTRESPONSE']._serialized_end=480
  _globals['_SEGMENT']._serialized_start=483
  _globals['_SEGMENT']._serialized_end=701
  _globals['_SEGMENT_SEGMENTTYPE']._serialized_start=677
  _globals['_SEGMENT_SEGMENTTYPE']._serialized_end=701
  _globals['_VOICEACTIVITYDETECTION']._serialized_start=704
  _globals['_VOICEACTIVITYDETECTION']._serialized_end=884
# @@protoc_insertion_point(module_scope)
