# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/core.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/core.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fphonexia/grpc/common/core.proto\x12\x14phonexia.grpc.common\x1a\x1egoogle/protobuf/duration.proto\"\x8d\x01\n\x05\x41udio\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x33\n\ntime_range\x18\x02 \x01(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\x12>\n\x10raw_audio_config\x18\x03 \x01(\x0b\x32$.phonexia.grpc.common.RawAudioConfig\"\xbf\x01\n\x0eRawAudioConfig\x12\x44\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32\x32.phonexia.grpc.common.RawAudioConfig.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\x12\x10\n\x08\x63hannels\x18\x03 \x01(\x05\":\n\rAudioEncoding\x12\t\n\x05PCM16\x10\x00\x12\t\n\x05PCM32\x10\x01\x12\t\n\x05MULAW\x10\x02\x12\x08\n\x04\x41LAW\x10\x03\"\x1d\n\nVoiceprint\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"C\n\x06Matrix\x12\x12\n\nrows_count\x18\x01 \x01(\x04\x12\x15\n\rcolumns_count\x18\x02 \x01(\x04\x12\x0e\n\x06values\x18\x03 \x03(\x02\"\x18\n\x06Vector\x12\x0e\n\x06values\x18\x01 \x03(\x02\"]\n\tTimeRange\x12(\n\x05start\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.core_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUDIO']._serialized_start=90
  _globals['_AUDIO']._serialized_end=231
  _globals['_RAWAUDIOCONFIG']._serialized_start=234
  _globals['_RAWAUDIOCONFIG']._serialized_end=425
  _globals['_RAWAUDIOCONFIG_AUDIOENCODING']._serialized_start=367
  _globals['_RAWAUDIOCONFIG_AUDIOENCODING']._serialized_end=425
  _globals['_VOICEPRINT']._serialized_start=427
  _globals['_VOICEPRINT']._serialized_end=456
  _globals['_MATRIX']._serialized_start=458
  _globals['_MATRIX']._serialized_end=525
  _globals['_VECTOR']._serialized_start=527
  _globals['_VECTOR']._serialized_end=551
  _globals['_TIMERANGE']._serialized_start=553
  _globals['_TIMERANGE']._serialized_end=646
# @@protoc_insertion_point(module_scope)
