# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/referential_deepfake_detection/v1/referential_deepfake_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/referential_deepfake_detection/v1/referential_deepfake_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\naphonexia/grpc/technologies/referential_deepfake_detection/v1/referential_deepfake_detection.proto\x12<phonexia.grpc.technologies.referential_deepfake_detection.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xf7\x01\n\rDetectRequest\x12\x36\n\x0f\x61udio_reference\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.AudioH\x00\x12\x37\n\x10\x61udio_questioned\x18\x04 \x01(\x0b\x32\x1b.phonexia.grpc.common.AudioH\x01\x12Z\n\x06\x63onfig\x18\x07 \x01(\x0b\x32J.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectConfigB\x0b\n\treferenceB\x0c\n\nquestioned\"@\n\x0c\x44\x65tectConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa7\x01\n\x0e\x44\x65tectResponse\x12Z\n\x06result\x18\x01 \x01(\x0b\x32J.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1d\n\x0c\x44\x65tectResult\x12\r\n\x05score\x18\x01 \x01(\x02\x32\xc6\x01\n\x1cReferentialDeepfakeDetection\x12\xa5\x01\n\x06\x44\x65tect\x12K.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectRequest\x1aL.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.referential_deepfake_detection.v1.referential_deepfake_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST']._serialized_start=229
  _globals['_DETECTREQUEST']._serialized_end=476
  _globals['_DETECTCONFIG']._serialized_start=478
  _globals['_DETECTCONFIG']._serialized_end=542
  _globals['_DETECTRESPONSE']._serialized_start=545
  _globals['_DETECTRESPONSE']._serialized_end=712
  _globals['_DETECTRESULT']._serialized_start=714
  _globals['_DETECTRESULT']._serialized_end=743
  _globals['_REFERENTIALDEEPFAKEDETECTION']._serialized_start=746
  _globals['_REFERENTIALDEEPFAKEDETECTION']._serialized_end=944
# @@protoc_insertion_point(module_scope)
