# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/denoiser/v1/denoiser.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/denoiser/v1/denoiser.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5phonexia/grpc/technologies/denoiser/v1/denoiser.proto\x12&phonexia.grpc.technologies.denoiser.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"<\n\x0e\x44\x65noiseRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\x93\x01\n\x0f\x44\x65noiseResponse\x12\x45\n\x06result\x18\x01 \x01(\x0b\x32\x35.phonexia.grpc.technologies.denoiser.v1.DenoiseResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\";\n\rDenoiseResult\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio2\x8a\x01\n\x08\x44\x65noiser\x12~\n\x07\x44\x65noise\x12\x36.phonexia.grpc.technologies.denoiser.v1.DenoiseRequest\x1a\x37.phonexia.grpc.technologies.denoiser.v1.DenoiseResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.denoiser.v1.denoiser_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DENOISEREQUEST']._serialized_start=162
  _globals['_DENOISEREQUEST']._serialized_end=222
  _globals['_DENOISERESPONSE']._serialized_start=225
  _globals['_DENOISERESPONSE']._serialized_end=372
  _globals['_DENOISERESULT']._serialized_start=374
  _globals['_DENOISERESULT']._serialized_end=433
  _globals['_DENOISER']._serialized_start=436
  _globals['_DENOISER']._serialized_end=574
# @@protoc_insertion_point(module_scope)
