# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEphonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting.proto\x12.phonexia.grpc.technologies.keyword_spotting.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"3\n\x07Keyword\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\x16\n\x0epronunciations\x18\x02 \x03(\t\"\xd4\x01\n\rDetectRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12I\n\x08keywords\x18\x02 \x03(\x0b\x32\x37.phonexia.grpc.technologies.keyword_spotting.v1.Keyword\x12L\n\x06\x63onfig\x18\x03 \x01(\x0b\x32<.phonexia.grpc.technologies.keyword_spotting.v1.DetectConfig\"J\n\x0c\x44\x65tectConfig\x12!\n\x14\x63onfidence_sharpness\x18\x01 \x01(\x02H\x00\x88\x01\x01\x42\x17\n\x15_confidence_sharpness\"\x81\x02\n\x0eMatchedKeyword\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\x15\n\rpronunciation\x18\x02 \x01(\t\x12p\n\x14pronunciation_source\x18\x03 \x01(\x0e\x32R.phonexia.grpc.technologies.keyword_spotting.v1.MatchedKeyword.PronunciationSource\"T\n\x13PronunciationSource\x12\x0e\n\nDICTIONARY\x10\x00\x12\r\n\tGENERATED\x10\x01\x12\x08\n\x04USER\x10\x02\x12\x14\n\x10PARTLY_GENERATED\x10\x03\"\xd7\x01\n\x05Match\x12-\n\nstart_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\r\n\x05score\x18\x04 \x01(\x02\x12O\n\x07keyword\x18\x05 \x01(\x0b\x32>.phonexia.grpc.technologies.keyword_spotting.v1.MatchedKeyword\"V\n\x0c\x44\x65tectResult\x12\x46\n\x07matches\x18\x01 \x03(\x0b\x32\x35.phonexia.grpc.technologies.keyword_spotting.v1.Match\"\x99\x01\n\x0e\x44\x65tectResponse\x12L\n\x06result\x18\x01 \x01(\x0b\x32<.phonexia.grpc.technologies.keyword_spotting.v1.DetectResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1b\n\x19ListAllowedSymbolsRequest\"A\n\x1aListAllowedSymbolsResponse\x12\x11\n\tgraphemes\x18\x01 \x03(\t\x12\x10\n\x08phonemes\x18\x02 \x03(\t2\xcd\x02\n\x0fKeywordSpotting\x12\x8b\x01\n\x06\x44\x65tect\x12=.phonexia.grpc.technologies.keyword_spotting.v1.DetectRequest\x1a>.phonexia.grpc.technologies.keyword_spotting.v1.DetectResponse(\x01\x30\x01\x12\xab\x01\n\x12ListAllowedSymbols\x12I.phonexia.grpc.technologies.keyword_spotting.v1.ListAllowedSymbolsRequest\x1aJ.phonexia.grpc.technologies.keyword_spotting.v1.ListAllowedSymbolsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.keyword_spotting.v1.keyword_spotting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_KEYWORD']._serialized_start=186
  _globals['_KEYWORD']._serialized_end=237
  _globals['_DETECTREQUEST']._serialized_start=240
  _globals['_DETECTREQUEST']._serialized_end=452
  _globals['_DETECTCONFIG']._serialized_start=454
  _globals['_DETECTCONFIG']._serialized_end=528
  _globals['_MATCHEDKEYWORD']._serialized_start=531
  _globals['_MATCHEDKEYWORD']._serialized_end=788
  _globals['_MATCHEDKEYWORD_PRONUNCIATIONSOURCE']._serialized_start=704
  _globals['_MATCHEDKEYWORD_PRONUNCIATIONSOURCE']._serialized_end=788
  _globals['_MATCH']._serialized_start=791
  _globals['_MATCH']._serialized_end=1006
  _globals['_DETECTRESULT']._serialized_start=1008
  _globals['_DETECTRESULT']._serialized_end=1094
  _globals['_DETECTRESPONSE']._serialized_start=1097
  _globals['_DETECTRESPONSE']._serialized_end=1250
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_start=1252
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_end=1279
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_start=1281
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_end=1346
  _globals['_KEYWORDSPOTTING']._serialized_start=1349
  _globals['_KEYWORDSPOTTING']._serialized_end=1682
# @@protoc_insertion_point(module_scope)
