# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speech_to_text/v1/speech_to_text.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/speech_to_text/v1/speech_to_text.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAphonexia/grpc/technologies/speech_to_text/v1/speech_to_text.proto\x12,phonexia.grpc.technologies.speech_to_text.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x01\n\x11TranscribeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x02 \x01(\x0b\x32>.phonexia.grpc.technologies.speech_to_text.v1.TranscribeConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"\xde\x01\n\x10TranscribeConfig\x12\x19\n\x11preferred_phrases\x18\x01 \x03(\t\x12_\n\x10\x61\x64\x64itional_words\x18\x02 \x03(\x0b\x32\x45.phonexia.grpc.technologies.speech_to_text.v1.RequestedAdditionalWord\x12N\n\x0cresult_types\x18\x03 \x03(\x0e\x32\x38.phonexia.grpc.technologies.speech_to_text.v1.ResultType\"C\n\x17RequestedAdditionalWord\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\x16\n\x0epronunciations\x18\x02 \x03(\t\"\xb6\x01\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x04type\x18\x04 \x01(\x0e\x32\x36.phonexia.grpc.technologies.speech_to_text.v1.ItemType\"\xbd\x01\n\x0eOneBestSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x05words\x18\x04 \x03(\x0b\x32\x32.phonexia.grpc.technologies.speech_to_text.v1.Word\"Y\n\x07OneBest\x12N\n\x08segments\x18\x01 \x03(\x0b\x32<.phonexia.grpc.technologies.speech_to_text.v1.OneBestSegment\"\x97\x01\n\x17NBestSegmentAlternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12-\n\nstart_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"s\n\x0cNBestSegment\x12\x63\n\x14segment_alternatives\x18\x01 \x03(\x0b\x32\x45.phonexia.grpc.technologies.speech_to_text.v1.NBestSegmentAlternative\"U\n\x05NBest\x12L\n\x08segments\x18\x01 \x03(\x0b\x32:.phonexia.grpc.technologies.speech_to_text.v1.NBestSegment\"\xe5\x01\n\x1f\x43onfusionNetworkWordAlternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12\x44\n\x04type\x18\x05 \x01(\x0e\x32\x36.phonexia.grpc.technologies.speech_to_text.v1.ItemType\"\x80\x01\n\x14\x43onfusionNetworkWord\x12h\n\x11word_alternatives\x18\x01 \x03(\x0b\x32M.phonexia.grpc.technologies.speech_to_text.v1.ConfusionNetworkWordAlternative\"e\n\x10\x43onfusionNetwork\x12Q\n\x05words\x18\x01 \x03(\x0b\x32\x42.phonexia.grpc.technologies.speech_to_text.v1.ConfusionNetworkWord\"\xab\x03\n\x10TranscribeResult\x12L\n\x08one_best\x18\x01 \x01(\x0b\x32\x35.phonexia.grpc.technologies.speech_to_text.v1.OneBestH\x00\x88\x01\x01\x12H\n\x06n_best\x18\x02 \x01(\x0b\x32\x33.phonexia.grpc.technologies.speech_to_text.v1.NBestH\x01\x88\x01\x01\x12^\n\x11\x63onfusion_network\x18\x03 \x01(\x0b\x32>.phonexia.grpc.technologies.speech_to_text.v1.ConfusionNetworkH\x02\x88\x01\x01\x12_\n\x10\x61\x64\x64itional_words\x18\x04 \x03(\x0b\x32\x45.phonexia.grpc.technologies.speech_to_text.v1.ResultingAdditionalWord\x12\x10\n\x08language\x18\x05 \x01(\tB\x0b\n\t_one_bestB\t\n\x07_n_bestB\x14\n\x12_confusion_network\"\x89\x01\n\x17ResultingAdditionalWord\x12\x10\n\x08spelling\x18\x01 \x01(\t\x12\\\n\x0epronunciations\x18\x02 \x03(\x0b\x32\x44.phonexia.grpc.technologies.speech_to_text.v1.ResultingPronunciation\"J\n\x16ResultingPronunciation\x12\x15\n\rpronunciation\x18\x01 \x01(\t\x12\x19\n\x11out_of_vocabulary\x18\x02 \x01(\x08\"\x9f\x01\n\x12TranscribeResponse\x12N\n\x06result\x18\x01 \x01(\x0b\x32>.phonexia.grpc.technologies.speech_to_text.v1.TranscribeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1b\n\x19ListAllowedSymbolsRequest\"Y\n\x1aListAllowedSymbolsResponse\x12\x11\n\tgraphemes\x18\x01 \x03(\t\x12\x10\n\x08phonemes\x18\x02 \x03(\t\x12\x16\n\x0eword_separator\x18\x03 \x01(\t*a\n\nResultType\x12\x18\n\x14RESULT_TYPE_ONE_BEST\x10\x00\x12\x16\n\x12RESULT_TYPE_N_BEST\x10\x01\x12!\n\x1dRESULT_TYPE_CONFUSION_NETWORK\x10\x02*\x81\x01\n\x08ItemType\x12\x12\n\x0eITEM_TYPE_WORD\x10\x00\x12\x15\n\x11ITEM_TYPE_SILENCE\x10\x01\x12\x1b\n\x17ITEM_TYPE_SEGMENT_START\x10\x02\x12\x19\n\x15ITEM_TYPE_SEGMENT_END\x10\x03\x12\x12\n\x0eITEM_TYPE_NULL\x10\x04\x32\xce\x02\n\x0cSpeechToText\x12\x93\x01\n\nTranscribe\x12?.phonexia.grpc.technologies.speech_to_text.v1.TranscribeRequest\x1a@.phonexia.grpc.technologies.speech_to_text.v1.TranscribeResponse(\x01\x30\x01\x12\xa7\x01\n\x12ListAllowedSymbols\x12G.phonexia.grpc.technologies.speech_to_text.v1.ListAllowedSymbolsRequest\x1aH.phonexia.grpc.technologies.speech_to_text.v1.ListAllowedSymbolsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speech_to_text.v1.speech_to_text_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESULTTYPE']._serialized_start=2856
  _globals['_RESULTTYPE']._serialized_end=2953
  _globals['_ITEMTYPE']._serialized_start=2956
  _globals['_ITEMTYPE']._serialized_end=3085
  _globals['_TRANSCRIBEREQUEST']._serialized_start=181
  _globals['_TRANSCRIBEREQUEST']._serialized_end=340
  _globals['_TRANSCRIBECONFIG']._serialized_start=343
  _globals['_TRANSCRIBECONFIG']._serialized_end=565
  _globals['_REQUESTEDADDITIONALWORD']._serialized_start=567
  _globals['_REQUESTEDADDITIONALWORD']._serialized_end=634
  _globals['_WORD']._serialized_start=637
  _globals['_WORD']._serialized_end=819
  _globals['_ONEBESTSEGMENT']._serialized_start=822
  _globals['_ONEBESTSEGMENT']._serialized_end=1011
  _globals['_ONEBEST']._serialized_start=1013
  _globals['_ONEBEST']._serialized_end=1102
  _globals['_NBESTSEGMENTALTERNATIVE']._serialized_start=1105
  _globals['_NBESTSEGMENTALTERNATIVE']._serialized_end=1256
  _globals['_NBESTSEGMENT']._serialized_start=1258
  _globals['_NBESTSEGMENT']._serialized_end=1373
  _globals['_NBEST']._serialized_start=1375
  _globals['_NBEST']._serialized_end=1460
  _globals['_CONFUSIONNETWORKWORDALTERNATIVE']._serialized_start=1463
  _globals['_CONFUSIONNETWORKWORDALTERNATIVE']._serialized_end=1692
  _globals['_CONFUSIONNETWORKWORD']._serialized_start=1695
  _globals['_CONFUSIONNETWORKWORD']._serialized_end=1823
  _globals['_CONFUSIONNETWORK']._serialized_start=1825
  _globals['_CONFUSIONNETWORK']._serialized_end=1926
  _globals['_TRANSCRIBERESULT']._serialized_start=1929
  _globals['_TRANSCRIBERESULT']._serialized_end=2356
  _globals['_RESULTINGADDITIONALWORD']._serialized_start=2359
  _globals['_RESULTINGADDITIONALWORD']._serialized_end=2496
  _globals['_RESULTINGPRONUNCIATION']._serialized_start=2498
  _globals['_RESULTINGPRONUNCIATION']._serialized_end=2572
  _globals['_TRANSCRIBERESPONSE']._serialized_start=2575
  _globals['_TRANSCRIBERESPONSE']._serialized_end=2734
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_start=2736
  _globals['_LISTALLOWEDSYMBOLSREQUEST']._serialized_end=2763
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_start=2765
  _globals['_LISTALLOWEDSYMBOLSRESPONSE']._serialized_end=2854
  _globals['_SPEECHTOTEXT']._serialized_start=3088
  _globals['_SPEECHTOTEXT']._serialized_end=3422
# @@protoc_insertion_point(module_scope)
