"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Health check definitions for gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HealthCheckRequest(google.protobuf.message.Message):
    """Request message for checking the health of a service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    service: builtins.str
    """The name of the service to check."""
    def __init__(
        self,
        *,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service", b"service"]) -> None: ...

Global___HealthCheckRequest: typing_extensions.TypeAlias = HealthCheckRequest

@typing.final
class HealthCheckResponse(google.protobuf.message.Message):
    """Response message for checking the health of a service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServingStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServingStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HealthCheckResponse._ServingStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: HealthCheckResponse._ServingStatus.ValueType  # 0
        """The serving status is unknown."""
        SERVING: HealthCheckResponse._ServingStatus.ValueType  # 1
        """The service is serving requests."""
        NOT_SERVING: HealthCheckResponse._ServingStatus.ValueType  # 2
        """The service is not serving requests."""

    class ServingStatus(_ServingStatus, metaclass=_ServingStatusEnumTypeWrapper):
        """The serving status of the checked service."""

    UNKNOWN: HealthCheckResponse.ServingStatus.ValueType  # 0
    """The serving status is unknown."""
    SERVING: HealthCheckResponse.ServingStatus.ValueType  # 1
    """The service is serving requests."""
    NOT_SERVING: HealthCheckResponse.ServingStatus.ValueType  # 2
    """The service is not serving requests."""

    STATUS_FIELD_NUMBER: builtins.int
    status: Global___HealthCheckResponse.ServingStatus.ValueType
    """The serving status of the checked service."""
    def __init__(
        self,
        *,
        status: Global___HealthCheckResponse.ServingStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

Global___HealthCheckResponse: typing_extensions.TypeAlias = HealthCheckResponse
