# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/emotion_recognition/v1/emotion_recognition.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/emotion_recognition/v1/emotion_recognition.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKphonexia/grpc/technologies/emotion_recognition/v1/emotion_recognition.proto\x12\x31phonexia.grpc.technologies.emotion_recognition.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\xa2\x01\n\x10RecognizeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12W\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x42.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"C\n\x0fRecognizeConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa2\x01\n\x11RecognizeResponse\x12R\n\x06result\x18\x01 \x01(\x0b\x32\x42.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x94\x01\n\x0fRecognizeResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12O\n\x06scores\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.emotion_recognition.v1.EmotionScore\"\xbc\x01\n\x0c\x45motionScore\x12\\\n\x07\x65motion\x18\x01 \x01(\x0e\x32K.phonexia.grpc.technologies.emotion_recognition.v1.EmotionScore.EmotionType\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\"9\n\x0b\x45motionType\x12\t\n\x05\x41NGRY\x10\x00\x12\x07\n\x03SAD\x10\x01\x12\t\n\x05HAPPY\x10\x02\x12\x0b\n\x07NEUTRAL\x10\x03\x32\xaf\x01\n\x12\x45motionRecognition\x12\x98\x01\n\tRecognize\x12\x43.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeRequest\x1a\x44.phonexia.grpc.technologies.emotion_recognition.v1.RecognizeResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.emotion_recognition.v1.emotion_recognition_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RECOGNIZEREQUEST']._serialized_start=196
  _globals['_RECOGNIZEREQUEST']._serialized_end=358
  _globals['_RECOGNIZECONFIG']._serialized_start=360
  _globals['_RECOGNIZECONFIG']._serialized_end=427
  _globals['_RECOGNIZERESPONSE']._serialized_start=430
  _globals['_RECOGNIZERESPONSE']._serialized_end=592
  _globals['_RECOGNIZERESULT']._serialized_start=595
  _globals['_RECOGNIZERESULT']._serialized_end=743
  _globals['_EMOTIONSCORE']._serialized_start=746
  _globals['_EMOTIONSCORE']._serialized_end=934
  _globals['_EMOTIONSCORE_EMOTIONTYPE']._serialized_start=877
  _globals['_EMOTIONSCORE_EMOTIONTYPE']._serialized_end=934
  _globals['_EMOTIONRECOGNITION']._serialized_start=937
  _globals['_EMOTIONRECOGNITION']._serialized_end=1112
# @@protoc_insertion_point(module_scope)
