# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/audio_quality_estimation/v1/audio_quality_estimation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/audio_quality_estimation/v1/audio_quality_estimation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUphonexia/grpc/technologies/audio_quality_estimation/v1/audio_quality_estimation.proto\x12\x36phonexia.grpc.technologies.audio_quality_estimation.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"=\n\x0f\x45stimateRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\x90\x03\n\x0e\x45stimateResult\x12\x1c\n\x0fpesq_estimation\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1f\n\x12signal_noise_ratio\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x19\n\x0c\x61udio_length\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x1a\n\rmax_amplitude\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x1a\n\rmin_amplitude\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x1b\n\x0epeak_amplitude\x18\x06 \x01(\x02H\x05\x88\x01\x01\x12\x1b\n\x0emean_amplitude\x18\x07 \x01(\x02H\x06\x88\x01\x01\x12\x1a\n\rsampling_rate\x18\x08 \x01(\x05H\x07\x88\x01\x01\x42\x12\n\x10_pesq_estimationB\x15\n\x13_signal_noise_ratioB\x0f\n\r_audio_lengthB\x10\n\x0e_max_amplitudeB\x10\n\x0e_min_amplitudeB\x11\n\x0f_peak_amplitudeB\x11\n\x0f_mean_amplitudeB\x10\n\x0e_sampling_rate\"\xa5\x01\n\x10\x45stimateResponse\x12V\n\x06result\x18\x01 \x01(\x0b\x32\x46.phonexia.grpc.technologies.audio_quality_estimation.v1.EstimateResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xba\x01\n\x16\x41udioQualityEstimation\x12\x9f\x01\n\x08\x45stimate\x12G.phonexia.grpc.technologies.audio_quality_estimation.v1.EstimateRequest\x1aH.phonexia.grpc.technologies.audio_quality_estimation.v1.EstimateResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.audio_quality_estimation.v1.audio_quality_estimation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ESTIMATEREQUEST']._serialized_start=210
  _globals['_ESTIMATEREQUEST']._serialized_end=271
  _globals['_ESTIMATERESULT']._serialized_start=274
  _globals['_ESTIMATERESULT']._serialized_end=674
  _globals['_ESTIMATERESPONSE']._serialized_start=677
  _globals['_ESTIMATERESPONSE']._serialized_end=842
  _globals['_AUDIOQUALITYESTIMATION']._serialized_start=845
  _globals['_AUDIOQUALITYESTIMATION']._serialized_end=1031
# @@protoc_insertion_point(module_scope)
