# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.keyword_spotting.v1 import keyword_spotting_pb2 as phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/keyword_spotting/v1/keyword_spotting_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class KeywordSpottingStub(object):
    """*
    Service implementing Keyword Spotting. For more information, see
    https://docs.cloud.phonexia.com/products/speech-platform-4/technologies/keyword-spotting/
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Detect = channel.stream_stream(
                '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/Detect',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectResponse.FromString,
                _registered_method=True)
        self.ListAllowedSymbols = channel.unary_unary(
                '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/ListAllowedSymbols',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsResponse.FromString,
                _registered_method=True)


class KeywordSpottingServicer(object):
    """*
    Service implementing Keyword Spotting. For more information, see
    https://docs.cloud.phonexia.com/products/speech-platform-4/technologies/keyword-spotting/
    """

    def Detect(self, request_iterator, context):
        """*
        Detect performs keyword spotting on the audio data.
        Returns detected keywords and their pronunciations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllowedSymbols(self, request, context):
        """*
        ListAllowedSymbols returns lists of allowed symbols for the keyword
        spotting model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KeywordSpottingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Detect': grpc.stream_stream_rpc_method_handler(
                    servicer.Detect,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectResponse.SerializeToString,
            ),
            'ListAllowedSymbols': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllowedSymbols,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class KeywordSpotting(object):
    """*
    Service implementing Keyword Spotting. For more information, see
    https://docs.cloud.phonexia.com/products/speech-platform-4/technologies/keyword-spotting/
    """

    @staticmethod
    def Detect(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/Detect',
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.DetectResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllowedSymbols(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/phonexia.grpc.technologies.keyword_spotting.v1.KeywordSpotting/ListAllowedSymbols',
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_keyword__spotting_dot_v1_dot_keyword__spotting__pb2.ListAllowedSymbolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
