# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n[phonexia/grpc/technologies/transcription_normalization/v1/transcription_normalization.proto\x12\x39phonexia.grpc.technologies.transcription_normalization.v1\x1a\x1egoogle/protobuf/duration.proto\"\xd4\x01\n\x10NormalizeRequest\x12T\n\x08segments\x18\x01 \x03(\x0b\x32\x42.phonexia.grpc.technologies.transcription_normalization.v1.Segment\x12_\n\x06\x63onfig\x18\x02 \x01(\x0b\x32J.phonexia.grpc.technologies.transcription_normalization.v1.NormalizeConfigH\x00\x88\x01\x01\x42\t\n\x07_config\"5\n\x0fNormalizeConfig\x12\x15\n\x08language\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\"i\n\x11NormalizeResponse\x12T\n\x08segments\x18\x01 \x03(\x0b\x32\x42.phonexia.grpc.technologies.transcription_normalization.v1.Segment\"\x89\x01\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x17\n\x0fpunctuated_text\x18\x04 \x01(\t\"\xc3\x01\n\x07Segment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12N\n\x05words\x18\x04 \x03(\x0b\x32?.phonexia.grpc.technologies.transcription_normalization.v1.Word2\xc9\x01\n\x1aTranscriptionNormalization\x12\xaa\x01\n\tNormalize\x12K.phonexia.grpc.technologies.transcription_normalization.v1.NormalizeRequest\x1aL.phonexia.grpc.technologies.transcription_normalization.v1.NormalizeResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.transcription_normalization.v1.transcription_normalization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NORMALIZEREQUEST']._serialized_start=187
  _globals['_NORMALIZEREQUEST']._serialized_end=399
  _globals['_NORMALIZECONFIG']._serialized_start=401
  _globals['_NORMALIZECONFIG']._serialized_end=454
  _globals['_NORMALIZERESPONSE']._serialized_start=456
  _globals['_NORMALIZERESPONSE']._serialized_end=561
  _globals['_WORD']._serialized_start=564
  _globals['_WORD']._serialized_end=701
  _globals['_SEGMENT']._serialized_start=704
  _globals['_SEGMENT']._serialized_end=899
  _globals['_TRANSCRIPTIONNORMALIZATION']._serialized_start=902
  _globals['_TRANSCRIPTIONNORMALIZATION']._serialized_end=1103
# @@protoc_insertion_point(module_scope)
